@@ -8,13 +8,6 @@ import readchar
 # from inquirer import errors
 
 
-# Fixes for python 3 compatibility
-try:
-    safe_input = raw_input
-except NameError:
-    safe_input = input
-
-
 class ConsoleRender(object):
     def __init__(self, key_generator=None, terminal=None, *args, **kwargs):
         super(ConsoleRender, self).__init__(*args, **kwargs)
@@ -28,8 +21,6 @@ class ConsoleRender(object):
                 '{t.red}>> {t.normal}{t.bold}{msg}{t.normal} '
                 .format(msg=message, t=self.terminal)
                 )
-        else:
-            self.render_in_bottombar('')
 
     def render_in_bottombar(self, message):
         with self.terminal.location(0, self.terminal.height - 1):
